<?php if ( ! defined( 'ABSPATH' ) ) exit;

function ddpassword_plugins_loaded() {
    require_once(DIVI_PASSWORDS_PLUGIN_DIR_PATH . 'includes/dondivi/dondivi-core.php');
    dondivi_add_plugin('DIVI_PASSWORDS_DD_ADMIN', 'DiviPasswords', 'divipasswords', DIVI_PASSWORDS_VERSION, DIVI_PASSWORDS_PLUGIN_PATH, true, 'divipasswords', 0);
}
add_action( 'plugins_loaded', 'ddpassword_plugins_loaded');

function ddpassword_init() {
    load_plugin_textdomain( 'divi_passwords', false, 'divipasswords/languages' ); 
    if ( function_exists( 'dondivi_main_page' ) ) {
		return;
    }
    if ( constant('DIVI_PASSWORDS_DD_ADMIN') === dondivi_latest_version() && ! function_exists( 'dondivi_get_options' )) {
        require_once(DIVI_PASSWORDS_PLUGIN_DIR_PATH . 'includes/dondivi/dondivi-functions.php');
        if (is_admin()) {
            require_once(DIVI_PASSWORDS_PLUGIN_DIR_PATH . 'includes/dondivi/dondivi-admin.php');
        }
    }
}
add_action( 'init', 'ddpassword_init' );

function ddpassword_enqueue_scripts() {
    wp_enqueue_script( 'divipasswords', DIVI_PASSWORDS_PLUGIN_DIR_URL . 'scripts/frontend-bundle.min.js', array( 'jquery' ), true, true );
    wp_enqueue_style( 'divipasswords', DIVI_PASSWORDS_PLUGIN_DIR_URL . 'style/style.min.css' );
}
add_action( 'wp_enqueue_scripts', 'ddpassword_enqueue_scripts', 999 ); // priority doesn't really matter here

function ddpassword_extensions_init() {

    function ddpassword_add_content($id, $content) {
        global $contents_array;
        $contents_array[$id] = $content;
        update_option('divi_passwords', $contents_array);
    }

    function ddpassword_add_fields($fields_unprocessed) {
        $fields = array(
            'dd_use_password' => array(
                'label'         => esc_html__( 'Password Protection', 'divi_passwords' ),
                'description'   => esc_html__( 'Password Protect this content', 'divi_passwords' ),
                'type'          => 'yes_no_button',
                'options'       => array(
                    'on'  => esc_html__( 'On', 'et_builder' ),
                    'off' => esc_html__( 'Off', 'et_builder' ),					
                ),
                'affects'       => array(
                    'dd_form_use_icon',
                    'dd_form_title',
                    'dd_form_password',
                    'dd_form_placeholder',
                    'dd_form_error',
                    'dd_form_submit',
                    'dd_form_remember',
                    'dd_form_color'
                ),
                'default'       => 'off',
            ),
            'dd_form_use_icon' => array(
                'label'             => esc_html__( 'Use Padlock Icon', 'divi_passwords' ),
                'description'       => esc_html__( 'Here you can choose whether an icon should be used instead of a custom image.', 'divi_passwords' ),
                'type'              => 'yes_no_button',
                'options'           => array( 'off' => esc_html__( 'No', 'et_builder' ), 'on'  => esc_html__( 'Yes', 'et_builder' ) ),
                'affects'           => array( 'dd_form_image' ),
                'default'           => 'on',
            ),
            'dd_form_image' => array(
                'label'                 => esc_html__( 'Image', 'et_builder' ),
                'description'           => esc_html__( 'Upload an image to display at the top of your form.', 'divi_passwords' ),
                'type'                  => 'upload',
                'upload_button_text'    => esc_html__( 'Upload an image', 'et_builder' ),
                'choose_text'           => esc_attr__( 'Choose an Image', 'et_builder' ),
                'update_text'           => esc_attr__( 'Set As Image', 'et_builder' ),
                'default'               => ET_BUILDER_PLACEHOLDER_LANDSCAPE_IMAGE_DATA,
                'depends_show_if'       => 'off',
            ),
            'dd_form_title' => array (
                'label'         => esc_html__( 'Title', 'divi_passwords' ),
                'description'   => esc_html__( 'Type the form title.', 'divi_passwords' ),
                'type'          => 'text',
                'default'       => esc_html__( 'RESTRICTED ACCESS', 'divi_passwords'),
            ),
            'dd_form_password' => array (
                'label'             => esc_html__( 'Password', 'divi_passwords' ),
                'description'       => esc_html__( 'Type the password. If empty, the form will not be displayed.', 'divi_passwords' ),
                'type'              => 'text',
                'dynamic_content' 	=> 'text',	
            ),
            'dd_form_placeholder' => array (
                'label'         => esc_html__( 'Placeholder', 'divi_passwords' ),
                'description'   => esc_html__( 'Type the text you want to use as placeholder for the password field.', 'divi_passwords' ),
                'type'          => 'text',
                'default'       => esc_html__( 'Enter your password...', 'divi_passwords' ),
            ),
            'dd_form_error' => array (
                'label'         => esc_html__( 'Error Message', 'divi_passwords' ),
                'description'   => esc_html__( 'Here you can define a custom error message on invalid passwords.', 'divi_passwords' ),
                'type'          => 'text',
                'default'       => esc_html__( 'Invalid Password! Forgot it? Please contact the website administrator.', 'divi_passwords' ),
            ),
            'dd_form_submit' => array (
                'label'         => esc_html__( 'Button Text', 'divi_passwords' ),
                'description'   => esc_html__( 'Type the button text.', 'divi_passwords' ),
                'type'          => 'text',
                'default'       => esc_html__( 'Submit', 'divi_passwords' ),
            ),
            'dd_form_remember' => array(
                'label'         => esc_html__( 'Remember Password', 'divi_passwords' ),
                'description'   => esc_html__( 'Here you can choose whether or not the password should be remembered on page reloads.', 'divi_passwords' ),
                'type'          => 'yes_no_button',
                'options'       => array( 'on'  => esc_html__( 'Yes', 'et_builder' ), 'off' => esc_html__( 'No', 'et_builder' ) ),
                'default'       => 'off',
            ),
            'dd_form_color' => array(
                'label'         => esc_html__( 'Form Color', 'divi_passwords' ),
                'description'   => esc_html__( 'Here you can define a custom color for your form elements.', 'divi_passwords' ),
				'type'          => 'color-alpha',
				'default'       => et_builder_accent_color(),
			),
        );
        foreach ($fields as $key => $value) {
            $fields[$key]['tab_slug'] = 'custom_css';
            $fields[$key]['toggle_slug'] = 'divi_passwords';
        }
        return array_merge($fields_unprocessed, $fields); 
    }

    $supported_modules = apply_filters( 'divi_passwords_supported_modules', array( 'et_pb_section', 'et_pb_row', 'et_pb_row_inner', 'et_pb_column', 'et_pb_column_inner', 'et_pb_accordion', 
    'et_pb_audio', 'et_pb_counters', 'et_pb_counter', 'et_pb_blog', 'et_pb_blurb', 'et_pb_button', 'et_pb_circle_counter', 'et_pb_code', 'et_pb_comments', 'et_pb_contact_form', 
    'et_pb_countdown_timer', 'et_pb_cta', 'et_pb_divider', 'et_pb_filterable_portfolio', 'et_pb_fullwidth_code', 'et_pb_fullwidth_header', 'et_pb_fullwidth_image', 'et_pb_fullwidth_map', 
    'et_pb_fullwidth_menu', 'et_pb_fullwidth_portfolio', 'et_pb_fullwidth_post_content', 'et_pb_fullwidth_post_slider', 'et_pb_fullwidth_post_title', 'et_pb_fullwidth_slider', 'et_pb_gallery', 
    'et_pb_image', 'et_pb_login', 'et_pb_map', 'et_pb_menu', 'et_pb_number_counter', 'et_pb_portfolio', 'et_pb_post_content', 'et_pb_post_slider', 'et_pb_post_title', 'et_pb_post_nav', 
    'et_pb_pricing_tables', 'et_pb_pricing_table', 'et_pb_search', 'et_pb_shop', 'et_pb_sidebar', 'et_pb_slider', 'et_pb_social_media_follow', 'et_pb_social_media_follow_network', 'et_pb_tabs', 
    'et_pb_team_member', 'et_pb_testimonial', 'et_pb_text', 'et_pb_toggle', 'et_pb_video', 'et_pb_video_slider', 'et_pb_wc_additional_info', 'et_pb_wc_add_to_cart', 'et_pb_wc_breadcrumb', 
    'et_pb_wc_cart_notice', 'et_pb_wc_cart_products', 'et_pb_wc_cart_totals', 'et_pb_wc_checkout_additional_info', 'et_pb_wc_checkout_billing', 'et_pb_wc_checkout_order_details', 
    'et_pb_wc_checkout_payment_info', 'et_pb_wc_checkout_shipping', 'et_pb_wc_cross_sells', 'et_pb_wc_description', 'et_pb_wc_gallery', 'et_pb_wc_images', 'et_pb_wc_meta', 'et_pb_wc_price', 
    'et_pb_wc_rating', 'et_pb_wc_related_products', 'et_pb_wc_reviews', 'et_pb_wc_stock', 'et_pb_wc_tabs', 'et_pb_wc_title', 'et_pb_wc_upsells', 'et_pb_divimenus', 'et_pb_divimenus_flex', 'et_pb_signatures',
    'dondivi_content_toggle', 'dondivi_gallery', 'dondivi_grid', 'dondivi_hotspots', 'dondivi_menu', 'dondivi_popup', 'dondivi_tabs', 'dondivi_timeline' ));
    
    foreach ($supported_modules as $module) {
        add_filter("et_pb_all_fields_unprocessed_{$module}",  'ddpassword_add_fields');
    }

    function ddpassword_blurb_assets( $modules ) {
        array_push( $modules, 'et_pb_blurb' );
        return $modules;
    }
    function ddpassword_blurb_assets_atf( $atf_modules, $content ) {
        if (strpos($content, 'dd_use_password="on"') !== false)
            array_push( $atf_modules, 'et_pb_blurb' );
        return $atf_modules;
    }
    add_filter( 'et_dynamic_assets_modules_atf', 'ddpassword_blurb_assets_atf', 20, 2 ); // executed if dynamic CSS is disabled and the page is cachable (not in ET cache)

    function ddpassword_get_contents() {
        $db_option = get_option( 'divi_passwords' );
        if (!$db_option) return array();
        else return $db_option;
    }
    
    function ddpassword_get_form($form_id, $remember, $render_slug, $module) {
        $color = $module->props['dd_form_color'];
        $image = '';
        $image_classes  = array( 'et-waypoint', 'et_pb_animation_top' );
        $password_classes = array('dd-password-protect', 'et_pb_section');

        if ($remember) $password_classes[] = 'dd-remember';
        
        if ($render_slug === 'et_pb_column') {
            $column_classes = explode(' ', $module->module_classname($render_slug));
            $password_classes[] = 'et_pb_column';
            $regex  = '/et_pb_column_\d_\d/';
            foreach ($column_classes as $column_class) {
                if ( preg_match($regex, $column_class, $matches) ) $password_classes[] = $matches[0];
            }   
        }

        if ( 'off' === $module->props['dd_form_use_icon'] ) {
            $image = sprintf('<img src="%1$s" class="%2$s" alt="Password Protected Form">', 
                esc_attr($module->props['dd_form_image']),
                esc_attr(implode( ' ', $image_classes ))
            );    
        } else {
            $icon_style     = sprintf( 'color: %1$s;', esc_attr( $color ) );
            $image_classes[] = 'et-pb-icon';
            $image = sprintf('<span class="%1$s" style="%2$s">&#xe06c;</span>', 
                esc_attr(implode( ' ', $image_classes )),
                esc_attr($icon_style)
            );
        }
        
        $image = $image ? sprintf( '<span class="et_pb_image_wrap">%1$s</span>', $image ) : '';
        $image = $image ? sprintf( '<div class="et_pb_main_blurb_image">%1$s</div>', $image) : '';

        ET_Builder_Element::set_style( $render_slug, array(
            'selector'    => sprintf( '#%1$s > .et_pb_row', $form_id),
            'declaration' => sprintf( 'border-color: %1$s;', esc_html($color)),
        ) );
        ET_Builder_Element::set_style( $render_slug, array(
            'selector'    => sprintf( '#%1$s input', $form_id),
            'declaration' => sprintf( 'border: 1px solid %1$s;', esc_html($color)),
        ) );
        ET_Builder_Element::set_style( $render_slug, array(
            'selector'    => sprintf( '#%1$s h4', $form_id),
            'declaration' => sprintf( 'color: %1$s;', esc_html($color)),
        ) );
        ET_Builder_Element::set_style( $render_slug, array(
            'selector'    => sprintf( '#%1$s button', $form_id),
            'declaration' => sprintf( 'background-color: %1$s;', esc_html($color)),
        ) );

        return sprintf('
            <div id="%1$s" class="%8$s">  
                <div class="et_pb_row">
                    <form class="dd-password-form et_pb_blurb" method="post" autocomplete="off">
                        <div class="et_pb_blurb_content">
                            %2$s
                            <div class="et_pb_blurb_container">
                                <h4>%3$s</h4> 
                                <input type="password" class="dd-password" placeholder="%4$s" name="dd_password" autocomplete="off" data-password="%5$s">
                                <p class="dd-password-error" style="display:none">%6$s</p>
                                <button name="submit" type="submit" class="dd-password-submit">%7$s</button> 
                            </div>
                        </div>
                    </form>
                </div>
            </div>', 
        $form_id, 
        et_core_esc_previously( $image ),
        esc_html($module->props['dd_form_title']),
        esc_attr($module->props['dd_form_placeholder']),  
        password_hash(esc_html($module->props['dd_form_password']), PASSWORD_DEFAULT),
        isset($module->props['dd_form_error']) ? esc_html($module->props['dd_form_error']) : __( 'Invalid Password! Forgot it? Please contact the website administrator.', 'divi_passwords' ),
        esc_html($module->props['dd_form_submit']),
        esc_attr(implode( ' ', $password_classes )) );
    }

    function ddpassword_get_modules( $modules, $post_type ) {
        foreach ($modules as &$module) {           
            if ( isset( $module->fields_unprocessed['dd_use_password'] ) ) {
    
                if ( ! isset( $module->settings_modal_toggles['custom_css']['toggles'] ) ) {
                    $module->settings_modal_toggles['custom_css']['toggles'] = array();
                }
                $module->settings_modal_toggles['custom_css']['toggles']['divi_passwords'] = array(
                    'title'    => esc_html__( 'Password', 'divi_passwords' ),
                    'priority' => 200,
                );
                $added_fields = array( 'dd_form_use_icon', 'dd_form_image', 'dd_form_title', 'dd_form_password', 'dd_form_placeholder', 'dd_form_error',  'dd_form_submit', 'dd_form_remember', 'dd_form_color' );
                foreach ($added_fields as $added_field) {
                    unset( $module->fields_unprocessed[$added_field]['vb_support'] );
                }
            }
        }
        unset($module);
        return $modules;
    }
    add_filter('et_builder_get_parent_modules', 'ddpassword_get_modules', 10, 2);
    add_filter('et_builder_get_child_modules', 'ddpassword_get_modules', 10, 2);

    function ddpassword_global_assets_list( $assets, $assets_args, $et_dynamic_assets ) {  
        
        if ( isset( $assets['et_icons_all'] ) ) return $assets;

        $content_retriever = \Feature\ContentRetriever\ET_Builder_Content_Retriever::init();
        $all_content = $content_retriever->get_entire_page_content();
        if (strpos($all_content, 'dd_use_password="on"') !== false) {
            $assets_prefix = et_get_dynamic_assets_path();
            $assets['et_icons_all'] = array( 'css' => "{$assets_prefix}/css/icons_all.css" );
        }
        return $assets;
    }
    add_filter( 'et_late_global_assets_list', 'ddpassword_global_assets_list', 10, 3);
    
    function ddpassword_handle_form() {

        $response = array( 'error' => __( 'An error has occurred, please contact the website administrator', 'divi_passwords' ) );       
        if ( isset($_POST['nonce'], $_POST['form_id'], $_POST['hash'], $_POST['password'], $_POST['error']) && wp_verify_nonce( $_POST['nonce'], 'et_frontend_nonce' ) ) {
            $form_id    = sanitize_text_field( $_POST['form_id'] );
            $hash       = sanitize_text_field( $_POST['hash'] );
            $password   = sanitize_text_field( $_POST['password'] );
            if ( isset( $password ) && password_verify($password, $hash)) {
                $contents = ddpassword_get_contents();
                $response = array(
                    'validation' => true,
                    'content' => $contents[$form_id],
                );
            } else {
                $response = array(
                    'error' => sanitize_text_field($_POST['error'] )
                );
            }
        }
        echo wp_json_encode( $response );
        wp_die();
    }
    add_action( 'wp_ajax_ddpassword_handle_form', 'ddpassword_handle_form' );
    add_action( 'wp_ajax_nopriv_ddpassword_handle_form', 'ddpassword_handle_form' );

    function ddpassword_is_remembered($form_id) {
        return (  isset($_COOKIE['divi_passwords']) && in_array( $form_id, explode(',', $_COOKIE['divi_passwords']) )  );
    }

    $contents_array = array();
    function ddpassword_shortcode_output ($output, $render_slug, $module) {
        if ( is_array($output) ) return $output;
        if ( !empty($output) && isset( $module->props['dd_use_password'] ) && $module->props['dd_use_password'] === 'on' && !empty($module->props['dd_form_password']) ) { 

            $form_id    = str_replace(' ', '', $module->module_classname($render_slug)) . get_the_ID(); // $module->classname 
            $remember   = $module->props['dd_form_remember'] === 'on';
            if ( $remember && ddpassword_is_remembered($form_id) ) {
                return $output;
            } else {
                ddpassword_add_content($form_id, $output);
                $form = ddpassword_get_form($form_id, $remember, $render_slug, $module);
                if ($render_slug === 'et_pb_contact_form')
                    $form .= sprintf('<div class="et_pb_protected_contact_form" style="display:none">%s</div>', $output);
                return $form;
            }
        }
        add_filter( 'et_required_module_assets', 'ddpassword_blurb_assets' ); // executed if dynamic CSS is disabled and the page is cachable (not in ET cache)
        return $output;
    }
    add_filter('et_module_shortcode_output', 'ddpassword_shortcode_output', 10, 999);
}
add_action( 'divi_extensions_init', 'ddpassword_extensions_init' );